var topics =
[
    [ "Plug-in Type used for subCategories", "group__plugType.html", "group__plugType" ],
    [ "VST busses", "group__vstBus.html", "group__vstBus" ],
    [ "Predefined Preset Attributes", "group__presetAttributes.html", "group__presetAttributes" ],
    [ "Context of State Restoration", "group__stateType.html", "group__stateType" ],
    [ "Predefined Musical Instrument", "group__musicalInstrument.html", "group__musicalInstrument" ],
    [ "Predefined Musical Style", "group__musicalStyle.html", "group__musicalStyle" ],
    [ "Predefined Musical Character", "group__musicalCharacter.html", "group__musicalCharacter" ],
    [ "Speaker Arrangements", "group__speakerArrangements.html", "group__speakerArrangements" ],
    [ "VST 3 Data Types", "group__vst3typedef.html", "group__vst3typedef" ],
    [ "Test Class: Interface for unit testing", "group__TestClass.html", "group__TestClass" ],
    [ "Graphical User Interface", "group__pluginGUI.html", "group__pluginGUI" ],
    [ "Wayland Frame", "group__waylandFrame.html", "group__waylandFrame" ]
];